@@ -3,11 +3,9 @@ import os
 import json
 from hestia_earth.schema import SchemaType, NESTED_SEARCHABLE_KEYS
 
-from ._s3_client import _load_from_bucket, _exists_in_bucket
+from .storage import _load_from_storage, _exists
 from .request import request_url, api_url, api_access_token
 
-AWS_BUCKET = os.getenv('AWS_BUCKET')
-
 
 def _match_key_value(key: str, value):
     first_key = key.split('.')[0]
@@ -28,7 +26,7 @@ def _retry_request_error(func, retry_max: int = 5):
     raise err
 
 
-def _safe_get_request(url: str):
+def _safe_get_request(url: str, res_error=None):
     def exec():
         try:
             headers = {'Content-Type': 'application/json'}
@@ -37,11 +35,11 @@ def _safe_get_request(url: str):
                 headers['X-Access-Token'] = access_token
             return requests.get(url, headers=headers).json()
         except requests.exceptions.RequestException:
-            return None
+            return res_error
     return _retry_request_error(exec)
 
 
-def _safe_post_request(url: str, body: dict):
+def _safe_post_request(url: str, body: dict, res_error={}):
     def exec():
         try:
             headers = {'Content-Type': 'application/json'}
@@ -50,7 +48,7 @@ def _safe_post_request(url: str, body: dict):
                 headers['X-Access-Token'] = access_token
             return requests.post(url, json.dumps(body), headers=headers).json()
         except requests.exceptions.RequestException:
-            return None
+            return res_error
     return _retry_request_error(exec)
 
 
@@ -119,7 +117,8 @@ def download_hestia(node_id: str, node_type=SchemaType.TERM, data_state='', mode
 
     try:
         jsonld_path = node_to_path(node_type, node_id, data_state)
-        return json.loads(_load_from_bucket(AWS_BUCKET, jsonld_path)) if AWS_BUCKET else fallback()
+        data = _load_from_storage(jsonld_path)
+        return json.loads(data) if data else None
     except ImportError:
         return fallback()
 
@@ -146,7 +145,7 @@ def node_exists(node_id: str, node_type=SchemaType.TERM) -> bool:
         return result is not None and '@id' in result
 
     try:
-        return _exists_in_bucket(AWS_BUCKET, node_to_path(node_type, node_id)) if AWS_BUCKET else fallback()
+        return _exists(node_to_path(node_type, node_id))
     except ImportError:
         return fallback()
 
