@@ -1,17 +1,15 @@
 from functools import reduce
-import os
 from io import StringIO
 import requests
 import csv
 import numpy
 
-from ._s3_client import _load_from_bucket
+from .storage import _load_from_storage
 from .request import request_url, web_url
 
 DELIMITER = '\t'
 ENCODING = 'ISO-8859-1'
 GLOSSARY_FOLDER = 'glossary/lookups'
-AWS_BUCKET = os.getenv('AWS_BUCKET_GLOSSARY')
 _memory = {}
 MISSING = -99999
 
@@ -73,12 +71,13 @@ def _download_lookup_data(filename: str):
         return requests.get(url).content.decode('utf-8')
 
     try:
-        return _load_from_bucket(AWS_BUCKET, filepath).decode('utf-8') if AWS_BUCKET else fallback()
+        data = _load_from_storage(filepath, glossary=True)
+        return data.decode('utf-8') if data else None
     except ImportError:
         return fallback()
 
 
-def download_lookup(filename: str, keep_in_memory: bool = False):
+def download_lookup(filename: str, keep_in_memory: bool = True):
     """
     Download lookup table from Hestia as csv into a `numpy.recarray`.
 
@@ -87,7 +86,7 @@ def download_lookup(filename: str, keep_in_memory: bool = False):
     filename : str
         The name on the file on the Hestia lookup repository.
     keep_in_memory: bool
-        Set to True if you want to store the file in memory for later use.
+        Set to False if you do NOT want to store the file in memory for later use.
 
     Returns
     -------
